"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Created by ztt on 2018/9/22.
 */
var TimeUtils = /** @class */ (function () {
    function TimeUtils() {
    }
    /**
     * 某天时间
     * @param day
     * @returns {{start: string, end: string}}
     */
    TimeUtils.getDayTime = function (num) {
        if (num === void 0) { num = 0; }
        var today = new Date();
        today.setDate(today.getDay() + num);
        var dateStr = this.format(today, this.FORMAT_YMD);
        return { start: dateStr + this.START_TIME_SUFFIX, end: dateStr + this.END_TIME_SUFFIX };
    };
    /**
     * 某周时间
     * @param num
     * @returns {string}
     */
    TimeUtils.getWeekTime = function (num) {
        if (num === void 0) { num = 0; }
        var today = new Date();
        var weekday = today.getDay() || 7;
        today.setDate(today.getDate() - weekday + 1 + 7 * num);
        var start = this.format(today, this.FORMAT_YMD);
        today.setDate(today.getDate() + 6);
        var end = this.format(today, this.FORMAT_YMD);
        return { start: start + this.START_TIME_SUFFIX, end: end + this.END_TIME_SUFFIX };
    };
    /**
     * 某月时间
     * @returns {Date}
     */
    TimeUtils.getMonthTime = function (num) {
        if (num === void 0) { num = 0; }
        var today = new Date();
        today.setMonth(today.getMonth() + num);
        today.setDate(1);
        var start = this.format(today, this.FORMAT_YMD);
        today.setMonth(today.getMonth() + 1);
        today.setDate(0);
        var end = this.format(today, this.FORMAT_YMD);
        return { start: start + this.START_TIME_SUFFIX, end: end + this.END_TIME_SUFFIX };
    };
    /**
     * 某季度时间
     * @returns {string}
     */
    TimeUtils.getSeasonTime = function (num) {
        if (num === void 0) { num = 0; }
        var today = new Date();
        var month = today.getMonth();
        if (month < 3) {
            today.setMonth(0);
        }
        else if (2 < month && month < 6) {
            today.setMonth(3);
        }
        else if (5 < month && month < 9) {
            today.setMonth(6);
        }
        else if (8 < month && month < 11) {
            today.setMonth(9);
        }
        today.setDate(1);
        var start = this.format(today, this.FORMAT_YMD);
        today.setMonth(today.getMonth() + 3);
        today.setDate(0);
        var end = this.format(today, this.FORMAT_YMD);
        return { start: start + this.START_TIME_SUFFIX, end: end + this.END_TIME_SUFFIX };
    };
    /**
     * 获取某年时间
     * @param num
     * @returns {{start: string, end: string}}
     */
    TimeUtils.getYearTime = function (num) {
        if (num === void 0) { num = 0; }
        var today = new Date();
        today.setDate(1);
        today.setMonth(0);
        var start = this.format(today, this.FORMAT_YMD);
        today.setMonth(12);
        today.setDate(0);
        var end = this.format(today, this.FORMAT_YMD);
        return { start: start + this.START_TIME_SUFFIX, end: end + this.END_TIME_SUFFIX };
    };
    TimeUtils.getByMilliseconds = function (mise) {
        if (mise == null) {
            return null;
        }
        else {
            var date = new Date();
            date.setTime(mise);
            return this.format(date, this.FORMAT_YMD);
        }
    };
    /**
     * 时间格式化
     * @param date
     * @param format
     * @returns {string}
     */
    TimeUtils.format = function (date, format) {
        if (format === void 0) { format = this.FORMAT_FULL_EN; }
        var o = {
            "M+": date.getMonth() + 1,
            "d+": date.getDate(),
            "h+": date.getHours(),
            "m+": date.getMinutes(),
            "s+": date.getSeconds(),
            "q+": Math.floor((date.getMonth() + 3) / 3),
            "S": date.getMilliseconds() //millisecond
        };
        if (/(y+)/.test(format)) {
            format = format.replace(RegExp.$1, (date.getFullYear() + "").substr(4 - RegExp.$1.length));
        }
        for (var k in o) {
            if (new RegExp("(" + k + ")").test(format)) {
                format = format.replace(RegExp.$1, RegExp.$1.length == 1 ? o[k] : ("00" + o[k]).substr(("" + o[k]).length));
            }
        }
        return format;
    };
    TimeUtils.FORMAT_FULL_EN = "yyyy-MM-dd hh:mm:ss";
    TimeUtils.FORMAT_FULL_CN = "yyyy年MM月dd日 hh时mm分ss秒";
    TimeUtils.FORMAT_YMD = "yyyy-MM-dd";
    TimeUtils.FORMAT_YMD_CN = "yyyy年MM月dd日";
    TimeUtils.START_TIME_SUFFIX = " 00:00:00";
    TimeUtils.END_TIME_SUFFIX = " 24:59:59";
    return TimeUtils;
}());
exports.TimeUtils = TimeUtils;
