/**
 * Created by ztt on 2018/9/22.
 */
export class TimeUtils{

    public static FORMAT_FULL_EN="yyyy-MM-dd hh:mm:ss";
    public static FORMAT_FULL_CN="yyyy年MM月dd日 hh时mm分ss秒";
    public static FORMAT_YMD="yyyy-MM-dd";
    public static FORMAT_YMD_CN="yyyy年MM月dd日";

    private static START_TIME_SUFFIX=" 00:00:00";
    private static END_TIME_SUFFIX=" 24:59:59";

    /**
     * 某天时间
     * @param day
     * @returns {{start: string, end: string}}
     */
    public static getDayTime(num=0){
        let today = new Date ();
        today.setDate(today.getDay()+num);
        let dateStr=this.format(today,this.FORMAT_YMD);
        return {start:dateStr+this.START_TIME_SUFFIX,end:dateStr+this.END_TIME_SUFFIX};
    }

    /**
     * 某周时间
     * @param num
     * @returns {string}
     */
    public static getWeekTime(num=0){
        let today = new Date ();
        let weekday = today.getDay()||7;
        today.setDate(today.getDate()-weekday+1+7*num);
        let start=this.format(today,this.FORMAT_YMD);
        today.setDate(today.getDate()+6);
        let end=this.format(today,this.FORMAT_YMD);
        return {start:start+this.START_TIME_SUFFIX,end:end+this.END_TIME_SUFFIX};
    }

    /**
     * 某月时间
     * @returns {Date}
     */
    public static getMonthTime(num=0){
        var today=new Date();
        today.setMonth(today.getMonth()+num);
        today.setDate(1);
        let start=this.format(today,this.FORMAT_YMD);
        today.setMonth(today.getMonth()+1);
        today.setDate(0);
        let end=this.format(today,this.FORMAT_YMD);
        return {start:start+this.START_TIME_SUFFIX,end:end+this.END_TIME_SUFFIX};
    }

    /**
     * 某季度时间
     * @returns {string}
     */
    public static getSeasonTime(num=0){
        var today=new Date();
        var month = today.getMonth();
        if(month <3 ){
            today.setMonth(0);
        }else if(2 < month && month < 6){
            today.setMonth(3);
        }else if(5 < month && month < 9){
            today.setMonth(6);
        }else if(8 < month && month < 11){
            today.setMonth(9);
        }
        today.setDate(1);
        let start=this.format(today,this.FORMAT_YMD);
        today.setMonth(today.getMonth()+3)
        today.setDate(0);
        let end=this.format(today,this.FORMAT_YMD);
        return {start:start+this.START_TIME_SUFFIX,end:end+this.END_TIME_SUFFIX};
    }

    /**
     * 获取某年时间
     * @param num
     * @returns {{start: string, end: string}}
     */
    public static getYearTime(num=0){
        var today=new Date();
        today.setDate(1);
        today.setMonth(0);
        let start=this.format(today,this.FORMAT_YMD);
        today.setMonth(12)
        today.setDate(0);
        let end=this.format(today,this.FORMAT_YMD);
        return {start:start+this.START_TIME_SUFFIX,end:end+this.END_TIME_SUFFIX};
    }

    public static getByMilliseconds(mise:number){
        if (mise == null) {
            return null;
        } else {
            var date = new Date();
            date.setTime(mise);
            return this.format(date,this.FORMAT_YMD);
        }
    }

    /**
     * 时间格式化
     * @param date
     * @param format
     * @returns {string}
     */
    public static format(date:Date,format=this.FORMAT_FULL_EN){
        let o:any = {
            "M+" : date.getMonth()+1, //month
            "d+" : date.getDate(), //day
            "h+" : date.getHours(), //hour
            "m+" : date.getMinutes(), //minute
            "s+" : date.getSeconds(), //second
            "q+" : Math.floor((date.getMonth()+3)/3), //quarter
            "S" : date.getMilliseconds() //millisecond
        };

        if(/(y+)/.test(format)) {
            format = format.replace(RegExp.$1, (date.getFullYear()+"").substr(4 - RegExp.$1.length));
        }

        for(let k in o) {
            if(new RegExp("("+ k +")").test(format)) {
                format = format.replace(RegExp.$1, RegExp.$1.length==1 ? o[k] : ("00"+ o[k]).substr((""+ o[k]).length));
            }
        }
        return format;
    }
}